@@ -20,4 +20,9 @@ class SyncTransport(base.Transport):
         self.exporter = exporter
 
     def export(self, datas):
+        # Used to suppress tracking of requests in export
+        execution_context.set_is_exporter(True)
         self.exporter.emit(datas)
+        # Reset the context
+        execution_context.set_is_exporter(False)
+
